@@ -1,12 +1,12 @@
 #coding=utf-8
-import physicsLab.electricity.elementsClass._elementClassHead as _elementClassHead
-import physicsLab.electricity.elementPin as _elementPin
 from typing import Union
+import physicsLab.electricity.elementPin as _elementPin
+import physicsLab.electricity.elementsClass._elementClassHead as _elementClassHead
 
 # 开关基类
 
 class _switch_Element(_elementClassHead.elementObject):
-    @_elementClassHead.element_Init_HEAD()
+    @_elementClassHead.element_Init_HEAD
     def __init__(self, x: Union[int, float] = 0, y: Union[int, float] = 0, z: Union[int, float] = 0, elementXYZ = None):
         self._arguments = {"ModelID": "", "Identifier": "", "IsBroken": False,
                           "IsLocked": False, "Properties": {"开关": 0, "锁定": 1.0},
@@ -72,7 +72,7 @@ class DPDT_Switch(_switch_Element):
 # 按钮开关
 @_elementClassHead.two_pin_ArtificialCircuit_Pin
 class Push_Switch(_elementClassHead.elementObject):
-    @_elementClassHead.element_Init_HEAD()
+    @_elementClassHead.element_Init_HEAD
     def __init__(self, x: Union[int, float] = 0, y: Union[int, float] = 0, z: Union[int, float] = 0, elementXYZ = None):
         self._arguments = {
             'ModelID': 'Push Switch', 'Identifier': '', 'IsBroken': False, 'IsLocked': False,
@@ -84,7 +84,7 @@ class Push_Switch(_elementClassHead.elementObject):
 # 一节电池
 @_elementClassHead.two_pin_ArtificialCircuit_Pin
 class Battery_Source(_elementClassHead.elementObject):
-    @_elementClassHead.element_Init_HEAD()
+    @_elementClassHead.element_Init_HEAD
     def __init__(self, x: Union[int, float] = 0, y: Union[int, float] = 0, z: Union[int, float] = 0, elementXYZ = None):
         self._arguments = {'ModelID': 'Battery Source', 'Identifier': '',
                            'IsBroken': False, 'IsLocked': False, 'Properties': {'最大功率': 16.2, '电压': 3.0, '内阻': 0.5},
@@ -95,7 +95,7 @@ class Battery_Source(_elementClassHead.elementObject):
 
 # 学生电源
 class Student_Source(_elementClassHead.elementObject):
-    @_elementClassHead.element_Init_HEAD()
+    @_elementClassHead.element_Init_HEAD
     def __init__(self, x: Union[int, float] = 0, y: Union[int, float] = 0, z: Union[int, float] = 0, elementXYZ = None):
         self._arguments = {'ModelID': 'Student Source', 'Identifier': '', 'IsBroken': False, 'IsLocked': False,
                            'Properties': {'交流电压': 3.0, '直流电压': 3.0, '开关': 0.0, '频率': 50.0},
@@ -128,7 +128,7 @@ class Student_Source(_elementClassHead.elementObject):
 # 电阻
 @_elementClassHead.two_pin_ArtificialCircuit_Pin
 class Resistor(_elementClassHead.elementObject):
-    @_elementClassHead.element_Init_HEAD()
+    @_elementClassHead.element_Init_HEAD
     def __init__(self, x: Union[int, float] = 0, y: Union[int, float] = 0, z: Union[int, float] = 0, elementXYZ = None):
         self._arguments = {'ModelID': 'Resistor', 'Identifier': '', 'IsBroken': False,
                            'IsLocked': False,
@@ -142,7 +142,7 @@ class Resistor(_elementClassHead.elementObject):
 # 保险丝
 @_elementClassHead.two_pin_ArtificialCircuit_Pin
 class Fuse_Component(_elementClassHead.elementObject):
-    @_elementClassHead.element_Init_HEAD()
+    @_elementClassHead.element_Init_HEAD
     def __init__(self, x: Union[int, float] = 0, y: Union[int, float] = 0, z: Union[int, float] = 0, elementXYZ = None):
         self._arguments = {'ModelID': 'Fuse Component', 'Identifier': '', 'IsBroken': False, 'IsLocked': False,
                            'Properties': {'开关': 1.0, '额定电流': 0.30000001192092896, '熔断电流': 0.5, '锁定': 1.0},
@@ -152,7 +152,7 @@ class Fuse_Component(_elementClassHead.elementObject):
 
 # 滑动变阻器
 class Slide_Rheostat(_elementClassHead.elementObject):
-    @_elementClassHead.element_Init_HEAD()
+    @_elementClassHead.element_Init_HEAD
     def __init__(self, x: Union[int, float] = 0, y: Union[int, float] = 0, z: Union[int, float] = 0, elementXYZ = None):
         self._arguments = {'ModelID': 'Slide Rheostat', 'Identifier': '', 'IsBroken': False, 'IsLocked': False,
                            'Properties': {'额定电阻': 10.0, '滑块位置': 0.0, '电阻1': 10, '电阻2': 10.0, '锁定': 1.0},
